
--Below is the Script to create tablespaces and the required permissions.
--These values are minimum installation values. Enterprise implementations typically require larger values than the minimum. 
--Please work with your CA Technical Services contact to determine appropriate implementation architecture and sizing for your environment.


-- Datamart tablespace
create tablespace CCCUSER_TBL
nologging
datafile 'C:\app\ccc-db\CCCUSER_TBL.dbf'
size 5120M reuse autoextend
on next 250M maxsize 30000M extent management local
segment space management auto;


-- Datamart indexes
create tablespace CCCUSER_IDX
nologging
datafile 'C:\app\ccc-db\CCCUSER_IDX.DBF'
size 1024M reuse autoextend
on next 250M maxsize 30000M extent management local
segment space management auto;


-- Staging tablespace
create tablespace CCCUSER_STAGING_TBL
nologging
datafile 'C:\app\ccc-db\CCCUSER_STAGING_TBL.dbf'
size 5120M reuse autoextend
on next 250M maxsize 7000M extent management local
segment space management auto;


-- Staging indexes
create tablespace CCCUSER_STAGING_IDX
nologging
datafile 'C:\app\ccc-db\CCCUSER_STAGING_IDX.DBF'
size 1024M reuse autoextend
on next 250M maxsize 3000M extent management local
segment space management auto;


-- Create User
CREATE USER CCCUSER IDENTIFIED BY "password" 
DEFAULT TABLESPACE CCCUSER_TBL 
TEMPORARY TABLESPACE TEMP 
PROFILE DEFAULT;


-- Authorizations for the Oracle database
-- The Capacity Command Center database user requires the following permissions:
-- 1. READ access to Oracle dictionary objects, including user_table and dual.
-- 2. CONNECT, ANALYZE ANY, CREATE VIEW, CREATE JOB, and RESOURCE privileges to the database user name.
-- 3. EXECUTE permission on the DBMS_RANDOM package.
-- 4. EXECUTE permission for the DBMS_XMLGEN package.
-- 5. EXECUTE permission for the DBMS_OUTPUT package.
-- 6. EXECUTE permission on the DBMS_SCHEDULER package.

-- Important: The process that is responsible for purging the data in the staging tables is dependent on the DBMS_ SCHEDULER package. 
-- Without the EXECUTE privilege, the daily purge process will not be able to purge data in the staging tables.

-- Permissions for partitioning:
To run the partitioning process, the CCC user must have the following privilege in addition to the other required permissions:
-- 1.Executive privilege on the DBMS_METADATA package
-- 2. Explicitly granted CREATE TABLE privilege

-- Permissions for CCCUSER
Grant CONNECT to CCCUSER;
Grant ANALYZE ANY to CCCUSER;
Grant CREATE VIEW to CCCUSER;
Grant CREATE JOB to CCCUSER;
Grant EXECUTE on DBMS_RANDOM to CCCUSER;
Grant EXECUTE on DBMS_SCHEDULER to CCCUSER;
Grant RESOURCE to CCCUSER;
Grant SELECT ANY DICTIONARY to CCCUSER;
Grant EXECUTE on DBMS_XMLGEN to CCCUSER;
Grant EXECUTE on DBMS_OUTPUT to CCCUSER;
Grant EXECUTE on DBMS_METADATA to CCCUSER;
Grant CREATE TABLE to CCCUSER;